<?php
/**
 * 2007-2023 PrestaShop and Contributors
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2023 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 * International Registered Trademark & Property of PrestaShop SA
 */
use Symfony\Component\DependencyInjection\ContainerInterface;

abstract class GlotioPsKernel
{
    /** @var AppKernel */
    private static $instance;

    /**
     * @return AppKernel
     *
     * @throws GlotioException
     */
    public static function getInstance()
    {
        if (!self::$instance) {
            if (file_exists(_PS_ROOT_DIR_ . '/app/AppKernel.php')) {
                require_once _PS_ROOT_DIR_ . '/app/AppKernel.php';
            }

            if (!class_exists('AppKernel') || !GlotioUtils::isPs17OrGreater()) {
                throw new GlotioException("Can't load Prestashop Symfony Kernel, AppKernel class not found. Is this Prestashop 1.7+?");
            }

            self::$instance = new AppKernel(_PS_MODE_DEV_ ? 'dev' : 'prod', _PS_MODE_DEV_);
            self::$instance->boot();

            /**
             * Set global $kernel variable. When Glotio API is invoked from front Prestashop Context, this container isn't loaded.
             * We need it to use Translation services and setup languages.
             *
             * @see SymfonyContainer::getInstance
             */
            if (!isset($GLOBALS['kernel']) || !$GLOBALS['kernel']) {
                $GLOBALS['kernel'] = self::$instance;
            }
        }

        return self::$instance;
    }

    /**
     * @return \PrestaShopBundle\Service\TranslationService
     */
    public static function translationService()
    {
        return self::getInstance()->getContainer()->get('prestashop.service.translation');
    }

    /**
     * @return \PrestaShop\PrestaShop\Core\Translation\Builder\TranslationCatalogueBuilder
     */
    public static function translationsCatalogue()
    {
        return self::getInstance()->getContainer()->get('prestashop.translation.builder.translation_catalogue');
    }

    /**
     * @return \PrestaShopBundle\Service\Cache\Refresh|null
     */
    public static function prestashopCacheRefresh()
    {
        return self::getInstance()->getContainer()->get('prestashop.cache.refresh', ContainerInterface::NULL_ON_INVALID_REFERENCE);
    }

    /**
     * @return \PrestaShopBundle\Translation\Provider\ExternalModuleLegacySystemProvider|\PrestaShopBundle\Translation\Provider\ModuleProvider
     */
    public static function moduleProvider()
    {
        $moduleProvider = self::getInstance()->getContainer()->get('prestashop.translation.external_module_provider', ContainerInterface::NULL_ON_INVALID_REFERENCE);
        if (!$moduleProvider) {
            $moduleProvider = self::getInstance()->getContainer()->get('prestashop.translation.module_provider');
        }

        return $moduleProvider;
    }

    /**
     * @return \PrestaShop\PrestaShop\Core\Translation\Storage\Provider\CatalogueProviderFactory
     */
    public static function catalogueProviderFactory()
    {
        $factory = self::getInstance()->getContainer()->get('prestashop.translation.provider.catalogue_provider_factory');

        // Ugly hack to be able to retrieve translations from two themes in the same request
        // Reset Prestashop inner cache hack
        try {
            $refClass = new \ReflectionClass($factory);
            $prop = $refClass->getProperty('providers');
            $prop->setAccessible(true);
            $prop->setValue($factory, array());
        } catch (Exception $ex) {
            // ignore reflection errors
        }

        return $factory;
    }

    /**
     * @return \PrestaShopBundle\Translation\Exporter\ThemeExporter
     */
    public static function themeExporter()
    {
        return self::getInstance()->getContainer()->get('prestashop.translation.theme.exporter');
    }
}
