<?php

declare(strict_types=1);

abstract class GlotioCoreTranslatableTables
{
    /**
     * @return array<string>
     */
    public static function tables()
    {
        static $tables;

        if (!$tables) {
            $tables = array(
                'attachment',
                'attribute',
                'attribute_group',
                'carrier',
                'cart_rule',
                'category',
                'cms',
                'cms_category',
                'contact',
                'country',
                'feature',
                'feature_value',
                'gender',
                'image',
                'manufacturer',
                'meta',
                'product',
                'supplier',
            );

            // Not present in all versions of Prestashop
            if (class_exists('CustomizationField')) {
                $tables[] = 'customization_field';
            }

            if (class_exists('ProductAttribute')) {
                $key = array_search('attribute', $tables);
                if ($key !== false) {
                    unset($tables[$key]);
                }

                $tables[] = 'product_attribute';
            }
        }

        return $tables;
    }

    /**
     * @param string $table
     *
     * @return bool
     */
    public static function isTranslatable($table)
    {
        return in_array($table, self::tables());
    }

    /**
     * @param string $table
     *
     * @return string
     */
    public static function tableToClassname($table)
    {
        $classname = null;

        if ($table === 'cms') {
            $classname = 'CMS';
        } elseif ($table === 'cms_category') {
            $classname = 'CMSCategory';
        } else {
            $classname = Tools::toCamelCase($table, true);
        }

        return $classname;
    }
}
