<?php

class GlotioTranslationCache
{
    const SOURCES_CACHE_FILENAME = 'translation_sources.cache.php';
    const THEME_TEXTS_CACHE_FILENAME = 'theme_texts.cache.php';

    /** @var string */
    private $cache_directory;

    /** @var string */
    private $cache_file;

    /** @var array */
    private $cache = array();

    /**
     * ModuleModelCache constructor.
     *
     * @param string $cache_file
     * @param string|null $cache_directory
     */
    public function __construct($cache_file, $cache_directory = null)
    {
        if (!$cache_directory) {
            $cache_directory = _PS_MODULE_DIR_ . 'glotio/cache/';
        }

        $this->cache_directory = rtrim($cache_directory, '/');
        $this->cache_file = $this->cache_directory . '/' . $cache_file;

        if ($this->isObsolete()) {
            $this->reset();
        } else {
            $this->load();
        }
    }

    /**
     * @return GlotioTranslationCache
     */
    public static function createForSources()
    {
        return new self(self::SOURCES_CACHE_FILENAME);
    }

    public static function createForThemeTexts()
    {
        return new self(self::THEME_TEXTS_CACHE_FILENAME);
    }

    /**
     * @return bool
     */
    public function exists()
    {
        return file_exists($this->cache_file);
    }

    /**
     * @param string $key
     * @param array $data
     */
    public function add($key, array $data)
    {
        $this->cache[$key] = $data;
        $this->store();
    }

    /**
     * @param string $key
     *
     * @return array|null
     */
    public function get($key)
    {
        return isset($this->cache[$key]) ? $this->cache[$key] : null;
    }

    /**
     * @return bool
     */
    public function isObsolete()
    {
        if (!$this->exists()) {
            return false;
        }

        $created_date_cache_file = date('Ymd', filemtime($this->cache_file));

        // 1 day cache is valid
        return $created_date_cache_file < date('Ymd');
    }

    public function load()
    {
        if ($this->exists()) {
            $data = include $this->cache_file;
            if (!$data || !is_array($data)) {
                $data = array();
            }

            $this->cache = $data;
        }
    }

    /**
     * @throws GlotioException
     */
    public function store()
    {
        if (!$this->cache) {
            return;
        }

        $write_index = file_put_contents($this->cache_file, "<?php\n\nreturn " . var_export($this->cache, true) . ';');
        if (!$write_index) {
            throw new GlotioException("Can't write to location [$this->cache_file]");
        }
    }

    /**
     * @return bool
     */
    public function reset()
    {
        $this->cache = array();

        $cache_file = $this->cache_file;
        if (file_exists($cache_file)) {
            return @unlink($cache_file);
        } else {
            return false;
        }
    }
}
